@@ -1,3 +1,5 @@
+"""A CLI for processing composite Wavefront OBJ files into a MuJoCo-conducive format."""
+
 import enum
 import logging
 import os
@@ -76,6 +78,12 @@ class VhacdArgs:
     """try to find optimal split plane location"""
 
 
+@dataclass(frozen=True)
+class TextureArgs:
+    resize_percent: float = 1.0
+    """resize the texture to this percentage of the original size"""
+
+
 @dataclass(frozen=True)
 class Args:
     obj_dir: str
@@ -93,6 +101,9 @@ class Args:
     """print verbose output"""
     vhacd_args: VhacdArgs = field(default_factory=VhacdArgs)
     """arguments to pass to V-HACD"""
+    texture_args: TextureArgs = field(default_factory=TextureArgs)
+    overwrite: bool = False
+    """overwrite previous run output"""
 
 
 @dataclass
@@ -147,6 +158,18 @@ class Material:
         return f"{Ks}"
 
 
+def resize_texture(filename: Path, texture_args: TextureArgs) -> None:
+    """Resize a texture to a percentage of its original size."""
+    if texture_args.resize_percent == 1.0:
+        return
+    image = Image.open(filename)
+    new_width = int(image.size[0] * texture_args.resize_percent)
+    new_height = int(image.size[1] * texture_args.resize_percent)
+    logging.info(f"Resizing {filename} to {new_width}x{new_height}")
+    image = image.resize((new_width, new_height), Image.LANCZOS)
+    image.save(filename)
+
+
 def decompose_convex(filename: Path, work_dir: Path, vhacd_args: VhacdArgs) -> bool:
     if not vhacd_args.enable:
         return False
@@ -228,12 +251,13 @@ def process_obj(filename: Path, args: Args) -> None:
     # and materials will be stored there.
     work_dir = filename.parent / filename.stem
     if work_dir.exists():
-        proceed = input(
-            f"{work_dir.resolve()} already exists, maybe from a previous run? "
-            "Proceeding will overwrite it.\nDo you wish to continue [y/n]: "
-        )
-        if proceed.lower() != "y":
-            return
+        if not args.overwrite:
+            proceed = input(
+                f"{work_dir.resolve()} already exists, maybe from a previous run? "
+                "Proceeding will overwrite it.\nDo you wish to continue [y/n]: "
+            )
+            if proceed.lower() != "y":
+                return
         shutil.rmtree(work_dir)
     work_dir.mkdir(exist_ok=True)
     logging.info(f"Saving processed meshes to {work_dir}")
@@ -300,6 +324,7 @@ def process_obj(filename: Path, args: Args) -> None:
                     image.save(dst_filename)
                     texture_name = dst_filename.name
                     mtl.map_Kd = texture_name
+                resize_texture(dst_filename, args.texture_args)
         logging.info("Done processing MTL file")
 
     logging.info("Processing OBJ file with trimesh")
@@ -343,7 +368,10 @@ def process_obj(filename: Path, args: Args) -> None:
             with open(work_dir / f"{mtl_name}.mtl", "w") as f:
                 f.write("".join(smtl))
             # Edit the mtllib line to point to the new MTL file.
-            savename = str(work_dir / f"{filename.stem}_{i}.obj")
+            if len(sub_mtls) > 1:
+                savename = str(work_dir / f"{filename.stem}_{i}.obj")
+            else:
+                savename = str(work_dir / f"{filename.stem}.obj")
             with open(savename, "r") as f:
                 lines = f.readlines()
             for i, line in enumerate(lines):
@@ -493,7 +521,7 @@ def process_obj(filename: Path, args: Args) -> None:
 
 
 def main() -> None:
-    args = dcargs.parse(Args)
+    args = dcargs.cli(Args, description=__doc__)
 
     if args.verbose:
         logging.getLogger().setLevel(logging.INFO)
